@@ -2,7 +2,7 @@
 
 import pathlib
 
-from .user import DATA_CACHE, USER_DIR
+from .user import USER_DIR
 
 
 # Suffixes.
@@ -22,26 +22,28 @@ TLD_ABSPATH = pathlib.Path(__file__).parents[2]
 EXCEL_INTERFACE_PROJECT_HELP = (
     TLD_ABSPATH / 'eagers' / 'read' / 'excel_interface_project_help.txt'
 )
-DATA_CACHE_PATH = pathlib.Path(DATA_CACHE).expanduser()
+DEMO_FILES_DIR = TLD_ABSPATH / 'eagers' / 'demo_files'
 USER_DIR_PATH = pathlib.Path(USER_DIR).expanduser()
 USER_DIR_DATA_RETRIEVAL = USER_DIR_PATH / 'data_retrieval'
 USER_DIR_EPLUS = USER_DIR_PATH / 'eplus_validation'
 USER_DIR_HYDRO_DATA = USER_DIR_PATH / 'hydro_data'
 USER_DIR_SIMRESULTS = USER_DIR_PATH / 'simulation_results'
 USER_DIR_DATASETS = USER_DIR_PATH / 'data_sets'
-USER_DIR_HDF5_DATASETS = USER_DIR_DATASETS / 'HDF5'
+USER_DIR_HDF5_DATASETS = USER_DIR_DATASETS / 'hdf5'
+USER_DIR_HDF5_NODEDATA_DATASETS = USER_DIR_HDF5_DATASETS / 'nodedata'
+USER_DIR_HDF5_WEATHER_DATASETS = USER_DIR_HDF5_DATASETS / 'weather'
 USER_DIR_BUILDINGS = USER_DIR_PATH / 'eplus_buildings'
 USER_DIR_ENERGYPLUS_WEATHER = USER_DIR_PATH / 'eplus_weather'
 USER_DIR_PROJECTS = USER_DIR_PATH / 'projects'
 USER_DIR_TESTDATA = USER_DIR_PATH / 'test_data'
 AUTO_CREATED_DIRS = [
-    DATA_CACHE_PATH,
     USER_DIR_DATA_RETRIEVAL,
     USER_DIR_EPLUS,
     USER_DIR_HYDRO_DATA,
     USER_DIR_SIMRESULTS,
     USER_DIR_DATASETS,
-    USER_DIR_HDF5_DATASETS,
+    USER_DIR_HDF5_NODEDATA_DATASETS,
+    USER_DIR_HDF5_WEATHER_DATASETS,
     USER_DIR_BUILDINGS,
     USER_DIR_ENERGYPLUS_WEATHER,
     USER_DIR_PROJECTS,
