@@ -12,8 +12,8 @@ ProjectTemplateReader
 TestDataTemplateReader
 """
 
-from abc import ABC, abstractmethod
 import json
+import pathlib
 
 import numpy as np
 from openpyxl import load_workbook, Workbook
@@ -29,7 +29,7 @@ from eagers.config.path_spec import (
     USER_DIR_PROJECTS, USER_DIR_TESTDATA,
 )
 from eagers.config.text import RUNTIME_HDF5_FILE_PREFIX
-from eagers.read.online_data import load_dataset
+from eagers.read.example_file import load_example_file
 from eagers.read.weather_file import read_weather_file
 from eagers.basic.datetime_ext import datetime_from_data
 from eagers.basic.file_handling import ensure_suffix
@@ -37,31 +37,23 @@ from eagers.basic.hdf5 import DatetimeFloatConverter as DFC
 from eagers.basic.hdf5 import  new_hdf5_file, write_records_to_new_hdf5_table, write_user_attributes
 
 
-class BaseTemplateHandler(ABC):
+class BaseTemplateHandler:
     """Defines functionality common between BaseTemplateWriter and
     BaseTemplateReader.
     """
 
+    # Subclass properties.
+    _default_filename: str
+    _save_dir: pathlib.Path
+
     _sheet_properties = {}
 
     def __init__(self):
         self._filename = self._default_filename
 
-    @property
-    @classmethod
-    @abstractmethod
-    def _default_filename(cls):
-        pass
-
-    @property
-    @classmethod
-    @abstractmethod
-    def _save_dir(cls):
-        pass
-
     @property
     def filename(self):
-        return self._filename
+        return ensure_suffix(self._filename, WORKBOOK_SUFFIX)
 
     @filename.setter
     def filename(self, value):
@@ -71,9 +63,8 @@ class BaseTemplateHandler(ABC):
             self._filename = self._default_filename
 
     @property
-    def filepath(self):
-        return ensure_suffix(
-            self._save_dir / self.filename, WORKBOOK_SUFFIX)
+    def filepath(self) -> pathlib.Path:
+        return self._save_dir / self.filename
 
 
 class ProjectTemplateHandler(BaseTemplateHandler):
@@ -137,8 +128,7 @@ class BaseTemplateWriter(BaseTemplateHandler):
         else:
             ws = wb.active
             ws.title = name
-        ws.sheet_properties.tabColor = cls._sheet_properties[name].get(
-            'tab_color')
+        ws.sheet_properties.tabColor = cls._sheet_properties[name].get('tab_color')
         # Call method for specific operations.
         return getattr(cls, cls._sheet_properties[name]['add_method'])(ws)
 
@@ -296,6 +286,10 @@ class BaseTemplateReader(BaseTemplateHandler):
     # 'Instructions' is just for user reference.
     _ignored_sheets = ('TimeSeriesInputs', 'Instructions')
 
+    # Subclass properties.
+    _example_filename: str
+    _user_dirpath: pathlib.Path
+
     def read(self, filename=None):
         """Read user data from filled in template.
 
@@ -308,9 +302,9 @@ class BaseTemplateReader(BaseTemplateHandler):
         self.filename = filename
         # Use "data_only" flag to avoid reading cell formulas.
         # https://stackoverflow.com/a/35624928/7232335
-        if filename == 'default_project':
+        if self.filename == self._example_filename:
             wb = load_workbook(
-                load_dataset('default_project.xlsx').name,
+                load_example_file(self._example_filename, self._user_dirpath),
                 read_only=True,
                 data_only=True,
             )
@@ -376,6 +370,7 @@ class BaseTemplateReader(BaseTemplateHandler):
 class ProjectTemplateReader(ProjectTemplateHandler, BaseTemplateReader):
     """Project template reader class."""
 
+    _example_filename = 'default_project.xlsx'
     _sheet_properties = {
         'Components': dict(
             read_method='_read_components_sheet',
@@ -393,6 +388,7 @@ class ProjectTemplateReader(ProjectTemplateHandler, BaseTemplateReader):
             read_method='_read_optimoptions_sheet',
         ),
     }
+    _user_dirpath = USER_DIR_PROJECTS
 
     def read(self, *args, **kwargs):
         """Overwrite BaseTemplateReader.read()."""
@@ -448,8 +444,10 @@ class ProjectTemplateReader(ProjectTemplateHandler, BaseTemplateReader):
         for row in values:
             filename = row[0]
             try:
-                build = Building.from_file(load_dataset(filename))
-            except:
+                build = Building.from_file(
+                    load_example_file(filename, USER_DIR_BUILDINGS)
+                )
+            except FileNotFoundError:
                 build = Building.from_file(USER_DIR_BUILDINGS / filename)
             build.filename = filename
             buildings.append(build)
@@ -593,6 +591,7 @@ class ProjectTemplateReader(ProjectTemplateHandler, BaseTemplateReader):
 class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
     """TestData template reader class."""
 
+    _example_filename = 'default_testdata.xlsx'
     _sheet_properties = {
         'NodeData': dict(
             read_method='_read_nodedata_sheet',
@@ -601,6 +600,7 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
             read_method='_read_weather_sheet',
         ),
     }
+    _user_dirpath = USER_DIR_TESTDATA
 
     def read(self, filename=None):
         """Overwrite BaseTemplateReader.read(). Read user data from
@@ -615,9 +615,9 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
         self.filename = filename
         # Use "data_only" flag to avoid reading cell formulas.
         # https://stackoverflow.com/a/35624928/7232335
-        if filename == 'default_testdata':
+        if self.filename == self._example_filename:
             wb = load_workbook(
-                load_dataset('default_testdata.xlsx').name,
+                load_example_file(self._example_filename, self._user_dirpath),
                 read_only=True,
                 data_only=True,
             )
@@ -792,10 +792,13 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
         if filename:
             try:
                 weather_data = read_weather_file(
-                    ensure_suffix(load_dataset(filename), EPW_SUFFIX),
+                    ensure_suffix(
+                        load_example_file(filename, USER_DIR_ENERGYPLUS_WEATHER),
+                        EPW_SUFFIX,
+                    ),
                     designation,
                 )
-            except:
+            except FileNotFoundError:
                 weather_data = read_weather_file(
                     ensure_suffix(USER_DIR_ENERGYPLUS_WEATHER / filename, EPW_SUFFIX),
                     designation,
